==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/cs_CZ.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenty",
"Can't create document" => "Nelze vytvořit dokument",
"You don't have permission to rename this document" => "Nemáte oprávnění pro přejmenování tohoto souboru",
"Directory saved successfully." => "Adresář byl úspěšně uložen.",
"An error occurred while changing directory." => "Při pokusu o změnu adresáře došlo k chybě.",
"Saved" => "Uloženo",
"Format filter server is down or misconfigured" => "Server pro zpracování formátu je nedostupný nebo chybně nakonfigurovaný",
"Conversion failed. Check log for details." => "Převod selhal. Zkontrolujte logy pro více detailů.",
"document-styles" => "document-styles",
"document-content" => "document-content",
"bold" => "tučné",
"italic" => "kurzíva",
"solid" => "pevný",
"pt" => "bod",
"Saving..." => "Ukládám...",
"Failed to load documents." => "Nepodařilo se načíst dokumenty.",
"No documents were found. Upload or create a document to get started!" => "Žádné dokumenty nebyly nalezeny. Začněte nahráním nebo vytvořením prvního dokumentu!",
"No connection to server. Trying to reconnect." => "Ztráta připojení k serveru. Zkouším znovu.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Ponecháním této stránky v módu editoru může dojít k neuložení změn. Místo toho je doporučeno použít tlačítko 'Zavřít'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Nepodařilo se otevřít tento dokument. Prosím zkontrolujte, zda je možné jej otevřít externím editorem odt. Může to také znamenat, že byl nedávno odsdílen nebo smazán.",
"Save" => "Uložit",
"Loading documents..." => "Nahrávám dokumenty ...",
"'.' is an invalid file name." => "'.' je neplatným názvem souboru.",
"File name cannot be empty." => "Název souboru nemůže být prázdný řetězec.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neplatný název, znaky '\\', '/', '<', '>', ':', '\"', '|', '?' a '*' nejsou povoleny.",
"Align Left" => "Zarovnat vlevo",
"Alignment" => "Zarovnání",
"Align Right" => "Zarovnat vpravo",
"Annotate" => "Komentovat",
"Background" => "Pozadí",
"Bold" => "Tučné",
"Bottom" => "Dolní",
"Cancel" => "Zrušit",
"Center" => "Vystředit",
"Clone" => "Klonovat",
"Clone this Style" => "Klonovat tento styl",
"Close" => "Zavřít",
"Color" => "Barva",
"Create" => "Vytvořit",
"Decrease Indent" => "Zmenšit odsazení",
"Default Style" => "Výchozí styl",
"Delete" => "Smazat",
"Family" => "Rodina",
"Font" => "Font",
"Font Effects" => "Efekty písma",
"Format" => "Formát",
"Increase Indent" => "Zvětšit odsazení",
"Insert Image" => "Vlož obrázek",
"Invite Members" => "Pozvat členy",
"Italic" => "Kurzíva",
"Justified" => "Zarovnaný",
"Justify" => "Zarovnat",
"Left" => "Vlevo",
"Loading" => "Načítám",
"Members" => "Členové",
"New Name:" => "Nový název:",
"OK" => "OK",
"Open" => "Otevřít",
"Options" => "Možnosti",
"Paragraph..." => "Odstavec...",
"Paragraph Styles" => "Styly odstavce",
"Redo" => "Znovu",
"Right" => "Vpravo",
"Size" => "Velikost",
"Spacing" => "Řádkování",
"Strikethrough" => "Přeškrtnuté",
"Style" => "Styl",
"Text" => "Text",
"Top" => "Horní",
"Underline" => "Podtržené",
"Undo" => "Zpět",
"Unknown Author" => "Autor neznámý",
"Edit" => "Upravit",
"Share" => "Sdílet",
"guest" => "host",
"MS Word support (requires openOffice/libreOffice)" => "Podpora MS Word (vyžaduje openOffice/libreOffice)",
"Local" => "Místní",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je nainstalován na tomto serveru. Cesta ke spustitelnému souboru je zaznamenána pod preview_libreoffice_path v config.php",
"External" => "Externí",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffie je nainstalován na externím serveru, kde běží instance filtrující formáty",
"Disabled" => "Zakázáno",
"No MS Word support" => "Žádná podpora MS Word",
"scheme://domain.tld[:port]" => "schéma://doména.tld[:port]",
"Server URL" => "URL serveru",
"Apply and test" => "Použít a otestovat",
"New document" => "Nový dokument",
"Upload (max. %s)" => "Nahrát (max. %s)",
"Upload" => "Odeslat",
"Save new documents to" => "Uložit nové dokumenty do",
"Wrong password. Please retry." => "Nesprávné heslo. Zkuste to znovu.",
"Password" => "Heslo",
"Guest %s" => "Host %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Tento odkaz vypršel nebo neexistuje. Pro podrobnosti kontaktujte osobu, která jej s vámi sdílela.",
"Advanced feature-set" => "Pokročilá sada možností",
"(Unstable)" => "(Nestabilní)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/cs_CZ.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenty",
"Can't create document" => "Nelze vytvořit dokument",
"You don't have permission to rename this document" => "Nemáte oprávnění pro přejmenování tohoto souboru",
"File does not exist" => "Soubor neexistuje",
"Directory saved successfully." => "Adresář byl úspěšně uložen.",
"An error occurred while changing directory." => "Při pokusu o změnu adresáře došlo k chybě.",
"Saved" => "Uloženo",
"Format filter server is down or misconfigured" => "Server pro zpracování formátu je nedostupný nebo chybně nakonfigurovaný",
"Conversion failed. Check log for details." => "Převod selhal. Zkontrolujte logy pro více detailů.",
"Saving..." => "Ukládám...",
"Failed to load documents." => "Nepodařilo se načíst dokumenty.",
"No documents were found. Upload or create a document to get started!" => "Žádné dokumenty nebyly nalezeny. Začněte nahráním nebo vytvořením prvního dokumentu!",
"No connection to server. Trying to reconnect." => "Ztráta připojení k serveru. Zkouším znovu.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Ponecháním této stránky v módu editoru může dojít k neuložení změn. Místo toho je doporučeno použít tlačítko 'Zavřít'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Nepodařilo se otevřít tento dokument. Prosím zkontrolujte, zda je možné jej otevřít externím editorem odt. Může to také znamenat, že byl nedávno odsdílen nebo smazán.",
"Save" => "Uložit",
"Loading documents..." => "Nahrávám dokumenty ...",
"'.' is an invalid file name." => "'.' je neplatným názvem souboru.",
"File name cannot be empty." => "Název souboru nemůže být prázdný řetězec.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neplatný název, znaky '\\', '/', '<', '>', ':', '\"', '|', '?' a '*' nejsou povoleny.",
"Align Left" => "Zarovnat vlevo",
"Alignment" => "Zarovnání",
"Align Right" => "Zarovnat vpravo",
"Annotate" => "Komentovat",
"Background" => "Pozadí",
"Bold" => "Tučné",
"Bottom" => "Dolní",
"Cancel" => "Zrušit",
"Center" => "Vystředit",
"Clone" => "Klonovat",
"Clone this Style" => "Klonovat tento styl",
"Close" => "Zavřít",
"Color" => "Barva",
"Create" => "Vytvořit",
"Decrease Indent" => "Zmenšit odsazení",
"Default Style" => "Výchozí styl",
"Delete" => "Smazat",
"Family" => "Rodina",
"Font" => "Font",
"Font Effects" => "Efekty písma",
"Format" => "Formát",
"Increase Indent" => "Zvětšit odsazení",
"Insert Image" => "Vlož obrázek",
"Invite Members" => "Pozvat členy",
"Italic" => "Kurzíva",
"Justified" => "Zarovnaný",
"Justify" => "Zarovnat",
"Left" => "Vlevo",
"Loading" => "Načítám",
"Members" => "Členové",
"New Name:" => "Nový název:",
"OK" => "OK",
"Open" => "Otevřít",
"Options" => "Možnosti",
"Paragraph..." => "Odstavec...",
"Paragraph Styles" => "Styly odstavce",
"Redo" => "Znovu",
"Right" => "Vpravo",
"Size" => "Velikost",
"Spacing" => "Řádkování",
"Strikethrough" => "Přeškrtnuté",
"Style" => "Styl",
"Text" => "Text",
"Top" => "Horní",
"Underline" => "Podtržené",
"Undo" => "Zpět",
"Unknown Author" => "Autor neznámý",
"Shared" => "Sdílené",
"Error" => "Chyba",
"Error while sharing" => "Chyba při sdílení",
"Error while unsharing" => "Chyba při rušení sdílení",
"Error while changing permissions" => "Chyba při změně oprávnění",
"Shared with you and the group {group} by {owner}" => "S Vámi a skupinou {group} sdílí {owner}",
"Shared with you by {owner}" => "S Vámi sdílí {owner}",
"Share with users or groups …" => "Sdílet s uživateli nebo skupinami",
"Share with users, groups or remote users …" => "Sdílet s uživateli, skupinami nebo vzdálenými uživateli",
"Share" => "Sdílet",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Sdílejte s lidmi na ownClouds použitím syntaxe username@example.com/owncloud",
"Share link" => "Sdílet odkaz",
"The public link will expire no later than {days} days after it is created" => "Veřejný odkaz vyprší nejpozději {days} dní od svého vytvoření",
"Link" => "Odkaz",
"Password protect" => "Chránit heslem",
"Password" => "Heslo",
"Choose a password for the public link" => "Zadej heslo pro tento veřejný odkaz",
"Allow editing" => "Povolit úpravy",
"Email link to person" => "Odeslat osobě odkaz emailem",
"Send" => "Odeslat",
"Set expiration date" => "Nastavit datum vypršení platnosti",
"Expiration" => "Konec platnosti",
"Expiration date" => "Datum vypršení platnosti",
"An error occured. Please try again" => "Nastala chyba. Prosím zkuste to znovu",
"Adding user..." => "Přidávám uživatele...",
"group" => "skupina",
"remote" => "vzdálený",
"Resharing is not allowed" => "Sdílení již sdílené položky není povoleno",
"Shared in {item} with {user}" => "Sdíleno v {item} s {user}",
"Unshare" => "Zrušit sdílení",
"notify by email" => "upozornit emailem",
"can share" => "může sdílet",
"can edit" => "lze upravovat",
"access control" => "řízení přístupu",
"create" => "vytvořit",
"change" => "změnit",
"delete" => "smazat",
"Password protected" => "Chráněno heslem",
"Error unsetting expiration date" => "Chyba při odstraňování data vypršení platnosti",
"Error setting expiration date" => "Chyba při nastavení data vypršení platnosti",
"Sending ..." => "Odesílám ...",
"Email sent" => "Email odeslán",
"Warning" => "Varování",
"Edit" => "Upravit",
"guest" => "host",
"MS Word support (requires openOffice/libreOffice)" => "Podpora MS Word (vyžaduje openOffice/libreOffice)",
"Local" => "Místní",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je nainstalován na tomto serveru. Cesta ke spustitelnému souboru je zaznamenána pod preview_libreoffice_path v config.php",
"External" => "Externí",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffie je nainstalován na externím serveru, kde běží instance filtrující formáty",
"Disabled" => "Zakázáno",
"No MS Word support" => "Žádná podpora MS Word",
"scheme://domain.tld[:port]" => "schéma://doména.tld[:port]",
"Server URL" => "URL serveru",
"Apply and test" => "Použít a otestovat",
"New document" => "Nový dokument",
"Upload (max. %s)" => "Nahrát (max. %s)",
"Upload" => "Odeslat",
"Save new documents to" => "Uložit nové dokumenty do",
"Wrong password. Please retry." => "Nesprávné heslo. Zkuste to znovu.",
"Guest %s" => "Host %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Tento odkaz vypršel nebo neexistuje. Pro podrobnosti kontaktujte osobu, která jej s vámi sdílela.",
"Advanced feature-set" => "Pokročilá sada možností",
"(Unstable)" => "(Nestabilní)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;";
